"use strict";
var BoothJS = (() => {
  var __defProp = Object.defineProperty;
  var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
  var __getOwnPropNames = Object.getOwnPropertyNames;
  var __hasOwnProp = Object.prototype.hasOwnProperty;
  var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
  var __export = (target, all) => {
    for (var name in all)
      __defProp(target, name, { get: all[name], enumerable: true });
  };
  var __copyProps = (to, from, except, desc) => {
    if (from && typeof from === "object" || typeof from === "function") {
      for (let key of __getOwnPropNames(from))
        if (!__hasOwnProp.call(to, key) && key !== except)
          __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
    }
    return to;
  };
  var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
  var __publicField = (obj, key, value) => {
    __defNormalProp(obj, typeof key !== "symbol" ? key + "" : key, value);
    return value;
  };

  // src/index.ts
  var src_exports = {};
  __export(src_exports, {
    AudioRecorder: () => AudioRecorder
  });

  // src/utils.ts
  async function getUserMedia(deviceId) {
    return navigator.mediaDevices.getUserMedia({
      audio: deviceId ? { deviceId } : true,
      video: false
    });
  }

  // src/recorder.ts
  var AudioRecorder = class {
    constructor(options = {}) {
      this.options = options;
      __publicField(this, "context");
      __publicField(this, "listeners", {});
      __publicField(this, "buffer", []);
      __publicField(this, "recorder");
      __publicField(this, "stream");
    }
    static async listDevices() {
      return navigator.mediaDevices.enumerateDevices().then((list) => list.filter((d) => d.kind === "audioinput"));
    }
    async start(deviceId) {
      this.recorder = await this.createAudioRecorder();
      this.recorder.start();
    }
    async stop() {
      return new Promise((resolve) => {
        var _a, _b, _c, _d, _e;
        (_a = this.recorder) == null ? void 0 : _a.addEventListener("stop", () => {
          resolve(this.flush());
        });
        (_b = this.recorder) == null ? void 0 : _b.stop();
        void ((_c = this.context) == null ? void 0 : _c.suspend());
        for (const track of (_e = (_d = this.stream) == null ? void 0 : _d.getTracks()) != null ? _e : []) {
          track.stop();
        }
      });
    }
    async installWorklet(name, path, callback) {
      const context = this.getAudioContext();
      const stream = await this.getAudioStream();
      await context.audioWorklet.addModule(path);
      const node = new AudioWorkletNode(context, name);
      await callback({ context, stream, node });
    }
    on(eventName, callback) {
      var _a;
      if (!this.listeners[eventName]) {
        this.listeners[eventName] = [];
      }
      (_a = this.listeners[eventName]) == null ? void 0 : _a.push(callback);
    }
    flush() {
      const blob = new Blob(this.buffer);
      this.buffer = [];
      return blob;
    }
    async createAudioRecorder() {
      const stream = await this.getAudioStream();
      const recorder = new MediaRecorder(stream, this.options);
      if ("volumechange" in this.listeners) {
        await this.setupAudioMeter();
      }
      recorder.addEventListener("dataavailable", ({ data }) => {
        var _a;
        if (data.size > 0) {
          (_a = this.buffer) == null ? void 0 : _a.push(data);
        }
      });
      return recorder;
    }
    fireEvent(name, event) {
      var _a, _b;
      for (const listener of (_b = (_a = this.listeners) == null ? void 0 : _a[name]) != null ? _b : []) {
        listener(event);
      }
    }
    async getAudioStream() {
      if (!this.stream) {
        this.stream = await getUserMedia();
      }
      return this.stream;
    }
    getAudioContext() {
      if (!this.context) {
        this.context = new AudioContext();
      }
      return this.context;
    }
    getWorkletPath(name) {
      var _a;
      return [(_a = this.options.workletPath) != null ? _a : "worklets", name].join("/");
    }
    async setupAudioMeter() {
      return this.installWorklet(
        "volume-meter",
        this.getWorkletPath("video-meter.js"),
        ({ node, context, stream }) => {
          const micNode = context.createMediaStreamSource(stream);
          node.port.addEventListener(
            "message",
            ({ data: volume }) => {
              this.fireEvent("volumechange", { volume });
            }
          );
          micNode.connect(node).connect(context.destination);
        }
      );
    }
  };
  return __toCommonJS(src_exports);
})();
//# sourceMappingURL=booth.js.map
